@@ -671,7 +671,7 @@ grid.text(x=0.25, y=y.coors[i], bubble_plot_labels.LEVELS[i], gp=gpar(col=format
 }
 
 if (!is.null(bubble_plot_data.LEVELS) & !is.null(bubble_plot_titles.NOTE)) {
-	stop('\n\n\t\t Both NOTE and LEVELS can not be used simulateously.  Please choose one and proceed.\n')
+	stop('\n\n\t\t Both NOTE and LEVELS cannot be used simulateously.  Please choose one and proceed.\n')
 }
 if (is.null(bubble_plot_data.LEVELS) & !is.null(bubble_plot_titles.NOTE)){
 	y.pos <- (nchar(bubble_plot_titles.NOTE)/300) * 0.35  # attempt to be adaptive with NOTE length...
@@ -681,9 +681,10 @@ if (is.null(bubble_plot_data.LEVELS) & !is.null(bubble_plot_titles.NOTE)){
 # Summary statistics
 
 y.coors <- 0.2
+coors.size <- max(min(bubble_plot_data.SIZE), 10)
 grid.text(x=0.5, y=y.coors+0.05, "Summary Statistics", gp=gpar(col=format.colors.font[1], fontface=2, cex=1.2))
 grid.text(x=0.5, y=y.coors, paste("Correlation:", round(cor(bubble_plot_data.X, bubble_plot_data.Y, use="complete.obs"), digits=2)))
-grid.text(x=0.5, y=y.coors-0.03, substitute(paste("Correlation (", N >= 10, "): ", correlation), list(correlation=round(cor(bubble_plot_data.X[bubble_plot_data.SIZE>=10], bubble_plot_data.Y[bubble_plot_data.SIZE>=10], use="complete.obs"), digits=2))))
+grid.text(x=0.5, y=y.coors-0.03, substitute(paste("Correlation (", N >= coor.size, "): ", correlation), list(coor.size=coors.size, correlation=round(cor(bubble_plot_data.X[bubble_plot_data.SIZE >= coors.size], bubble_plot_data.Y[bubble_plot_data.SIZE >= coors.size], use="complete.obs"), digits=2))))
 
 popViewport() ## pop right.legend.vp
 }
