@@ -3,7 +3,7 @@ function(my.config,
 	config.type="Standard") {
 
 	if (config.type=="Standard") {
-		
+
 		for (i in seq_along(my.config)) {
 			my.config[[i]][['sgp.content.areas']] <- my.config[[i]][['sgp.content.areas']][!is.na(my.config[[i]][['sgp.content.areas']])]
 			my.config[[i]][['sgp.panel.years']] <- my.config[[i]][['sgp.panel.years']][!is.na(my.config[[i]][['sgp.panel.years']])]
@@ -11,7 +11,7 @@ function(my.config,
 			my.config[[i]][['sgp.grade.sequences']] <- my.config[[i]][['sgp.grade.sequences']][!is.na(my.config[[i]][['sgp.grade.sequences']])]
 			my.config[[i]][['sgp.grade.sequences']] <- as.character(my.config[[i]][['sgp.grade.sequences']])
 			if (length(my.config[[i]][['sgp.projection.grade.sequences']]) > 0) {
-				my.config[[i]][['sgp.projection.grade.sequences']] <- 
+				my.config[[i]][['sgp.projection.grade.sequences']] <-
 					my.config[[i]][['sgp.projection.grade.sequences']][!is.na(my.config[[i]][['sgp.projection.grade.sequences']])]
 				tmp.min <- min(length(my.config[[i]][['sgp.content.areas']]), length(my.config[[i]][['sgp.projection.grade.sequences']]))
 				my.config[[i]][['sgp.projection.grade.sequences']] <- tail(as.character(my.config[[i]][['sgp.projection.grade.sequences']]), tmp.min)
@@ -29,9 +29,9 @@ function(my.config,
 	if (config.type=="Baseline") {
 
 		if (!all(unlist(sapply(lapply(my.config, names),
-			function(x) x %in% c("sgp.baseline.content.areas", "sgp.baseline.panel.years", "sgp.baseline.grade.sequences", "sgp.baseline.grade.sequences.lags", "sgp.baseline.panel.years.within", "sgp.baseline.exclude.sequences"))))) {
+			function(x) x %in% c("sgp.baseline.content.areas", "sgp.baseline.panel.years", "sgp.baseline.grade.sequences", "sgp.baseline.grade.sequences.lags", "sgp.baseline.panel.years.within", "sgp.baseline.exclude.sequences", "sgp.baseline.calculate.simex.baseline"))))) {
 				stop("Please specify an appropriate list of SGP function labels (sgp.baseline.config).  See help page for details.")
-		}       
+		}
 
 		for (i in seq_along(my.config)) {
 			my.config[[i]][['sgp.baseline.content.areas']] <- my.config[[i]][['sgp.baseline.content.areas']][!is.na(my.config[[i]][['sgp.baseline.content.areas']])]
