@@ -27,6 +27,7 @@ function(
 
 	ID <- CONTENT_AREA <- YEAR <- GRADE <- YEAR_INTEGER_TMP <- ACHIEVEMENT_LEVEL <- CATCH_UP_KEEP_UP_STATUS_INITIAL <- MOVE_UP_STAY_UP_STATUS_INITIAL <- VALID_CASE <- N <- SGP <- NULL
 	MOVE_UP_STAY_UP_STATUS <- CATCH_UP_KEEP_UP_STATUS <- ACHIEVEMENT_LEVEL_PRIOR <- target.type <- SGP_PROJECTION_GROUP <- DUPS_FLAG <- i.DUPS_FLAG <- SCALE_SCORE <- SGP_NORM_GROUP_SCALE_SCORES <- NULL
+	SGP_NORM_GROUP_BASELINE_SCALE_SCORES <- SGP_NORM_GROUP_EQUATED_SCALE_SCORES <- NULL
 
 	tmp.messages <- NULL
 
@@ -46,7 +47,7 @@ function(
 		tmp.name <- toupper(gsub("_", " ", deparse(substitute(sgp_object))))
 		tmp.name.position <- sapply(c(datasets::state.name, "AOB", "DEMONSTRATION"), function(x) regexpr(toupper(x), tmp.name))
 		if (any(tmp.name.position!=-1)) {
-			state <- c(datasets::state.abb, "AOB", "DEMO")[which(names(sort(tmp.name.position[tmp.name.position!=-1])[1])==c(datasets::state.name, "AOB", "DEMONSTRATION"))]
+			state <- c(datasets::state.abb, "AOB", "DEMO")[which(names(sort(tmp.name.position[tmp.name.position!=-1])[1L])==c(datasets::state.name, "AOB", "DEMONSTRATION"))]
 		} else {
 			tmp.messages <- c(tmp.messages, "\tNOTE: argument 'state' required for target SGP calculation. Target SGPs will not be calculated.\n")
 			sgp.projections.lagged <- sgp.projections.lagged.baseline <- FALSE
@@ -148,12 +149,15 @@ function(
 
 		if (identical(system.type, "Cohort Referenced")) {
 			tmp.list[['target.type']] <- intersect(target.type, c("sgp.projections", "sgp.projections.lagged"))
+			tmp.list[['my.sgp']] <- "SGP"
 			if (!is.null(year.for.equate) && tmp.first.year < year.for.equate && !sgp.percentiles.equated) {
 				tmp.variable.name <- paste("SGP_FROM", year.for.equate, sep="_")
-				tmp.messages <- c(tmp.messages, paste0("\tNOTE: Due to test transition in ", year.for.equate, " SGP_TARGET will be compared to ", tmp.variable.name, ".\n"))
+				messageSGP(paste0("\tNOTE: Due to assessment transition in ", year.for.equate, " SGP_TARGET will be compared to ", tmp.variable.name, ".\n"))
 				tmp.list[['my.sgp']] <- tmp.variable.name
-			} else {
-				tmp.list[['my.sgp']] <- "SGP"
+			}
+			if (!is.null(year.for.equate) && tmp.last.year==year.for.equate && sgp.percentiles.equated) {
+				messageSGP(paste0("\tNOTE: Due to test transition in ", year.for.equate, " SGP_TARGET will be compared to SGP_EQUATED.\n"))
+				tmp.list[['my.sgp']] <- "SGP_EQUATED"
 			}
 			tmp.list[['my.sgp.target']] <- paste("SGP_TARGET", max.sgp.target.years.forward, projection.unit.label, sep="_")
 			tmp.list[['my.sgp.target.content_area']] <- paste("SGP_TARGET", max.sgp.target.years.forward, projection.unit.label, "CONTENT_AREA", sep="_")
@@ -170,12 +174,15 @@ function(
 		}
 		if (identical(system.type, "Cohort and Baseline Referenced")) {
 			tmp.list[['target.type']] <- intersect(target.type, c("sgp.projections", "sgp.projections.baseline", "sgp.projections.lagged", "sgp.projections.lagged.baseline"))
+			tmp.list[['my.sgp']] <- c("SGP", "SGP_BASELINE")[c(sgp.percentiles, sgp.percentiles.baseline)]
 			if (!is.null(year.for.equate) && !sgp.percentiles.equated) {
-				tmp.year.diff <- as.numeric(unlist(strsplit(tail(sort(unique(sgp_object@Data, by='YEAR')[['YEAR']]), 1), "_"))[1]) - as.numeric(unlist(strsplit(year.for.equate, "_"))[1])
-				tmp.messages <- c(tmp.messages, paste0("\tNOTE: Due to test transition in ", year.for.equate, " SGP_TARGET will utilize ", paste("SGP_MAX_ORDER", tmp.year.diff, sep="_"), ".\n"))
+				tmp.year.diff <- as.numeric(unlist(strsplit(tail(sort(unique(sgp_object@Data, by='YEAR')[['YEAR']]), 1), "_"))[1L]) - as.numeric(unlist(strsplit(year.for.equate, "_"))[1L])
+				messageSGP(paste0("\tNOTE: Due to test transition in ", year.for.equate, " SGP_TARGET will utilize ", paste("SGP_MAX_ORDER", tmp.year.diff, sep="_"), ".\n"))
 				tmp.list[['my.sgp']] <- c(paste("SGP_MAX_ORDER", tmp.year.diff, sep="_"), "SGP_BASELINE")[c(sgp.percentiles, sgp.percentiles.baseline)]
-			} else {
-				tmp.list[['my.sgp']] <- c("SGP", "SGP_BASELINE")[c(sgp.percentiles, sgp.percentiles.baseline)]
+			}
+			if (!is.null(year.for.equate) && tmp.last.year==year.for.equate && sgp.percentiles.equated) {
+				messageSGP(paste0("\tNOTE: Due to test transition in ", year.for.equate, " SGP_TARGET will be compared to SGP_EQUATED.\n"))
+				tmp.list[['my.sgp']] <- "SGP_EQUATED"
 			}
 			tmp.list[['my.sgp.target']] <- c(paste("SGP_TARGET", max.sgp.target.years.forward, projection.unit.label, sep="_"),
 				paste("SGP_TARGET_BASELINE", max.sgp.target.years.forward, projection.unit.label, sep="_"))
@@ -247,7 +254,7 @@ function(
 
 	## Determine names of Cohort Referenced SGPs
 
-	if (!sgp.target.scale.scores.only && length(tmp.names <- getPercentileTableNames(sgp_object, content_areas, state, years, "sgp.percentiles", sgp.percentiles.equated)) == 0 && sgp.percentiles) {
+	if (!sgp.target.scale.scores.only && length(tmp.names <- getPercentileTableNames(sgp_object, content_areas, state, years, "sgp.percentiles", sgp.percentiles.equated=FALSE)) == 0 && sgp.percentiles) {
 		tmp.messages <- c(tmp.messages, "\tNOTE: No cohort referenced SGP results available in SGP slot. No cohort referenced SGP results will be merged.\n")
 		sgp.percentiles <- FALSE
 	}
@@ -257,7 +264,7 @@ function(
 		tmp.list <- list()
 		for (i in tmp.names) {
 		tmp.list[[i]] <- data.table(
-					CONTENT_AREA=unlist(strsplit(i, "[.]"))[1],
+					CONTENT_AREA=unlist(strsplit(i, "[.]"))[1L],
 					YEAR=getTableNameYear(i),
 					sgp_object@SGP[["SGPercentiles"]][[i]])
 		}
@@ -277,7 +284,7 @@ function(
 			##  Extend the slot.data if any new rows are required (e.g. dups in prior years) - if not still merge in DUPS_FLAG.
 			slot.data.extension <- tmp.data[!is.na(DUPS_FLAG), c(key(slot.data), "SGP_NORM_GROUP_SCALE_SCORES", "DUPS_FLAG"), with=FALSE]
 			tmp.split <- strsplit(as.character(slot.data.extension[["SGP_NORM_GROUP_SCALE_SCORES"]]), "; ")
-			invisible(slot.data.extension[, SCALE_SCORE := as.numeric(sapply(tmp.split, function(x) rev(x)[1]))])
+			invisible(slot.data.extension[, SCALE_SCORE := as.numeric(sapply(tmp.split, function(x) rev(x)[1L]))])
 			invisible(slot.data.extension[, SGP_NORM_GROUP_SCALE_SCORES := NULL])
 			if ("DUPS_FLAG" %in% names(slot.data)) flag.fix <- TRUE else flag.fix <- FALSE
 			slot.data <- slot.data.extension[slot.data, on=c(key(slot.data),"SCALE_SCORE"), allow.cartesian=TRUE]
@@ -305,7 +312,7 @@ function(
 
 	## Determine names of Baseline Referenced SGPs
 
-	if (!sgp.target.scale.scores.only && length(tmp.names <- getPercentileTableNames(sgp_object, content_areas, state, years, "sgp.percentiles.baseline"))==0 && sgp.percentiles.baseline) {
+	if (!sgp.target.scale.scores.only && length(tmp.names <- getPercentileTableNames(sgp_object, content_areas, state, years, "sgp.percentiles.baseline", sgp.percentiles.equated=FALSE))==0 && sgp.percentiles.baseline) {
 		 tmp.messages <- c(tmp.messages, "\tNOTE: No baseline referenced SGP results available in SGP slot. No baseline referenced SGP results will be merged.\n")
 		 sgp.percentiles.baseline <- FALSE
 	}
@@ -315,7 +322,7 @@ function(
 		tmp.list <- list()
 		for (i in tmp.names) {
 			tmp.list[[i]] <- data.table(
-				CONTENT_AREA=unlist(strsplit(i, "[.]"))[1],
+				CONTENT_AREA=unlist(strsplit(i, "[.]"))[1L],
 				YEAR=getTableNameYear(i),
 				sgp_object@SGP[["SGPercentiles"]][[i]])
 
@@ -341,10 +348,68 @@ function(
 			invisible(tmp.data[, ID := gsub("_DUPS_[0-9]*", "", ID)])
 
 			##  Extend the slot.data if any new rows are required (e.g. dups in prior years) - if not still merge in DUPS_FLAG.
-			slot.data.extension <- tmp.data[!is.na(DUPS_FLAG), c(key(slot.data), "SGP_NORM_GROUP_SCALE_SCORES", "DUPS_FLAG"), with=FALSE]
-			tmp.split <- strsplit(as.character(slot.data.extension[["SGP_NORM_GROUP_SCALE_SCORES"]]), "; ")
-			invisible(slot.data.extension[, SCALE_SCORE := as.numeric(sapply(tmp.split, function(x) rev(x)[1]))])
-			invisible(slot.data.extension[, SGP_NORM_GROUP_SCALE_SCORES := NULL])
+			slot.data.extension <- tmp.data[!is.na(DUPS_FLAG), c(key(slot.data), "SGP_NORM_GROUP_BASELINE_SCALE_SCORES", "DUPS_FLAG"), with=FALSE]
+			tmp.split <- strsplit(as.character(slot.data.extension[["SGP_NORM_GROUP_BASELINE_SCALE_SCORES"]]), "; ")
+			invisible(slot.data.extension[, SCALE_SCORE := as.numeric(sapply(tmp.split, function(x) rev(x)[1L]))])
+			invisible(slot.data.extension[, SGP_NORM_GROUP_BASELINE_SCALE_SCORES := NULL])
+			if ("DUPS_FLAG" %in% names(slot.data)) flag.fix <- TRUE else flag.fix <- FALSE
+			slot.data <- slot.data.extension[slot.data, on=c(key(slot.data),"SCALE_SCORE"), allow.cartesian=TRUE]
+			if (flag.fix) { # Merge together DUPS_FLAG from previous years
+				invisible(slot.data[!is.na(i.DUPS_FLAG) & is.na(DUPS_FLAG), DUPS_FLAG := i.DUPS_FLAG])
+				invisible(slot.data[, i.DUPS_FLAG := NULL])
+			}
+
+			##  Get the row index for variable merge.
+			tmp.index <- slot.data[tmp.data[, c(getKey(slot.data), "GRADE", "DUPS_FLAG"), with=FALSE], which=TRUE, on=c(getKey(slot.data), "GRADE", "DUPS_FLAG")] #
+		} else {
+			tmp.index <- slot.data[tmp.data[, key(tmp.data), with=FALSE], which=TRUE, on=key(tmp.data)]
+		}
+
+		variables.to.merge <- setdiff(names(tmp.data), c(getKey(slot.data), "GRADE"))
+		invisible(slot.data[tmp.index, (variables.to.merge):=tmp.data[, variables.to.merge, with=FALSE]])
+
+		setkeyv(slot.data, getKey(slot.data))
+	}
+
+
+	###################################################################################
+	### sgp.percentiles.equated: Merge equated SGPs in transition year
+	###################################################################################
+
+	## Determine names of Equated SGPs
+
+	if (!sgp.target.scale.scores.only && length(tmp.names <- getPercentileTableNames(sgp_object, content_areas, state, years, "sgp.percentiles", sgp.percentiles.equated=TRUE))==0 && sgp.percentiles.equated) {
+		 tmp.messages <- c(tmp.messages, "\tNOTE: No equated SGP results available in SGP slot. No equated SGP results will be merged.\n")
+		 sgp.percentiles.equated <- TRUE
+	}
+
+	if (sgp.percentiles.equated & !sgp.target.scale.scores.only) {
+
+		tmp.list <- list()
+		for (i in tmp.names) {
+			tmp.list[[i]] <- data.table(
+				CONTENT_AREA=unlist(strsplit(i, "[.]"))[1L],
+				YEAR=getTableNameYear(i),
+				sgp_object@SGP[["SGPercentiles"]][[i]])
+		}
+
+		tmp.data <- data.table(rbindlist(tmp.list, fill=TRUE), VALID_CASE="VALID_CASE", key=key(slot.data))
+
+		if (any(duplicated(tmp.data, by=key(tmp.data)))) {
+			tmp.data <- getPreferredSGP(tmp.data, state, type="BASELINE")
+		}
+
+		if (!is.null(fix.duplicates) & any(grepl("_DUPS_[0-9]*", tmp.data[["ID"]]))) {
+			##  Strip ID of the _DUPS_ Flag, but keep in a seperate variable (used to merge subsequently)
+			invisible(tmp.data[, DUPS_FLAG := gsub(".*_DUPS_", "", ID)])
+			invisible(tmp.data[!grepl("_DUPS_[0-9]*", ID), DUPS_FLAG := NA])
+			invisible(tmp.data[, ID := gsub("_DUPS_[0-9]*", "", ID)])
+
+			##  Extend the slot.data if any new rows are required (e.g. dups in prior years) - if not still merge in DUPS_FLAG.
+			slot.data.extension <- tmp.data[!is.na(DUPS_FLAG), c(key(slot.data), "SGP_NORM_GROUP_EQUATED_SCALE_SCORES", "DUPS_FLAG"), with=FALSE]
+			tmp.split <- strsplit(as.character(slot.data.extension[["SGP_NORM_GROUP_EQUATED_SCALE_SCORES"]]), "; ")
+			invisible(slot.data.extension[, SCALE_SCORE := as.numeric(sapply(tmp.split, function(x) rev(x)[1L]))])
+			invisible(slot.data.extension[, SGP_NORM_GROUP_EQUATED_SCALE_SCORES := NULL])
 			if ("DUPS_FLAG" %in% names(slot.data)) flag.fix <- TRUE else flag.fix <- FALSE
 			slot.data <- slot.data.extension[slot.data, on=c(key(slot.data),"SCALE_SCORE"), allow.cartesian=TRUE]
 			if (flag.fix) { # Merge together DUPS_FLAG from previous years
@@ -471,7 +536,7 @@ function(
 		if (identical(sgp.target.content_areas, TRUE)) {
 			for (my.sgp.target.content_area.iter in seq_along(target.args[['my.sgp.target.content_area']])) {
 				slot.data[!is.na(get(target.args[['my.sgp.target']][my.sgp.target.content_area.iter])), target.args[['my.sgp.target.content_area']][my.sgp.target.content_area.iter] :=
-					getTargetSGPContentArea(GRADE[1], CONTENT_AREA[1], state, max.sgp.target.years.forward, target.args[['my.sgp.target.content_area']][my.sgp.target.content_area.iter]),
+					getTargetSGPContentArea(GRADE[1L], CONTENT_AREA[1L], state, max.sgp.target.years.forward, target.args[['my.sgp.target.content_area']][my.sgp.target.content_area.iter]),
 					by=list(GRADE, CONTENT_AREA)]
 			}
 		}
@@ -495,7 +560,7 @@ function(
 					}
 					if (grepl("FROM", target.args[['my.sgp']][i])) slot.data[YEAR <= year.for.equate, target.args[['my.sgp']][i]:=SGP] ### Get comparison values from before transition
 					if (my.label %in% names(slot.data)) slot.data[,(my.label):=NULL]
-					slot.data[,(my.label):=rep(as.character(NA), dim(slot.data)[1])]
+					slot.data[,(my.label):=rep(as.character(NA), dim(slot.data)[1L])]
 
 					slot.data[CATCH_UP_KEEP_UP_STATUS_INITIAL == "Keeping Up" & get(target.args[['my.sgp']][i]) >= get(my.target.label),
 						(my.label):="Keep Up: Yes"]
@@ -546,7 +611,7 @@ function(
 					if (!grepl("BASELINE", target.args[['my.sgp']][i])) my.label <- paste("MOVE_UP_STAY_UP_STATUS", target.years.iter, "YEAR", sep="_") else my.label <- paste("MOVE_UP_STAY_UP_STATUS_BASELINE", target.years.iter, "YEAR", sep="_")
 					if (grepl("FROM", target.args[['my.sgp']][i])) slot.data[YEAR <= year.for.equate, target.args[['my.sgp']][i]:=SGP]
 					if (my.label %in% names(slot.data)) slot.data[,(my.label):=NULL]
-					slot.data[,(my.label):=rep(as.character(NA), dim(slot.data)[1])]
+					slot.data[,(my.label):=rep(as.character(NA), dim(slot.data)[1L])]
 
 					slot.data[MOVE_UP_STAY_UP_STATUS_INITIAL == "Staying Up" & get(target.args[['my.sgp']][i]) >= get(my.target.label),
 						(my.label):="Stay Up: Yes"]
@@ -599,7 +664,7 @@ function(
 						key=c(getKey(sgp_object), "SGP_PROJECTION_GROUP"))
 			}
 		}
-		tmp.target.data <- data.table(Reduce(function(x, y) merge(x, y, all=TRUE, by=intersect(names(y), names(x))), tmp.target.list[!sapply(tmp.target.list, function(x) dim(x)[1]==0)],
+		tmp.target.data <- data.table(Reduce(function(x, y) merge(x, y, all=TRUE, by=intersect(names(y), names(x))), tmp.target.list[!sapply(tmp.target.list, function(x) dim(x)[1L]==0L)],
 			accumulate=FALSE), key=getKey(slot.data))
 
 		if (!is.null(fix.duplicates)) {
