@@ -4,14 +4,14 @@ function(tmp.data,
 	current.year,
 	equating.method) {
 
-	VALID_CASE <- YEAR <- CONTENT_AREA <- GRADE <- NULL
+	VALID_CASE <- YEAR <- CONTENT_AREA <- GRADE <- V1 <- V2 <- NULL
 
 	tmp.list <- equate.list <- list()
 	equate.interval.digits <- SGP::SGPstateData[[state]][["Assessment_Program_Information"]][["Assessment_Transition"]][["Equate_Interval_Digits"]]
 	if (is.null(equate.interval.digits)) equate.interval.digits <- 0
 
 	current.year <- SGP::SGPstateData[[state]][["Assessment_Program_Information"]][["Assessment_Transition"]][["Year"]]
-	prior.year <- tail(head(sort(unique(tmp.data[['YEAR']])), -1), 1)
+	prior.year <- tail(head(sort(unique(tmp.data[['YEAR']])), -1L), 1L)
 	current.year.data <- tmp.data[VALID_CASE=="VALID_CASE" & YEAR==current.year]
 	prior.year.data <- tmp.data[VALID_CASE=="VALID_CASE" & YEAR==prior.year]
 	setkey(current.year.data, CONTENT_AREA, GRADE)
@@ -33,10 +33,10 @@ function(tmp.data,
 			if (year %in% tmp.knots.boundaries.years) {
 				return(paste0("[['", content_area, ".", year, "']]"))
 			} else {
-				if (year==sort(c(year, tmp.knots.boundaries.years))[1]) {
+				if (year==sort(c(year, tmp.knots.boundaries.years))[1L]) {
 					return(paste0("[['", content_area, "']]"))
 				} else {
-					return(paste0("[['", content_area, ".", rev(sort(tmp.knots.boundaries.years))[1], "']]"))
+					return(paste0("[['", content_area, ".", rev(sort(tmp.knots.boundaries.years))[1L], "']]"))
 				}
 			}
 		} else {
@@ -51,14 +51,14 @@ function(tmp.data,
 			equate.list[[toupper(equate.type.iter)]] <- list(
 				NEW_TO_OLD=equate(
 					freqtab(as.numeric(as.character(round(current.year.data[['SCALE_SCORE']], digits=equate.interval.digits))),
-						scales=as.numeric(as.character(round(seq(current.year.data.range[1], current.year.data.range[2], by=0.1^equate.interval.digits), digits=equate.interval.digits)))),
+						scales=as.numeric(as.character(round(seq(current.year.data.range[1L], current.year.data.range[2L], by=0.1^equate.interval.digits), digits=equate.interval.digits)))),
 					freqtab(as.numeric(as.character(round(prior.year.data[['SCALE_SCORE']], digits=equate.interval.digits))),
-						scales=as.numeric(as.character(round(seq(prior.year.data.range[1], prior.year.data.range[2], by=0.1^equate.interval.digits), digits=equate.interval.digits)))), type=equate.type.iter),
+						scales=as.numeric(as.character(round(seq(prior.year.data.range[1L], prior.year.data.range[2L], by=0.1^equate.interval.digits), digits=equate.interval.digits)))), type=equate.type.iter),
 				OLD_TO_NEW=equate(
 					freqtab(as.numeric(as.character(round(prior.year.data[['SCALE_SCORE']], digits=equate.interval.digits))),
-						scales=as.numeric(as.character(round(seq(prior.year.data.range[1], prior.year.data.range[2], by=0.1^equate.interval.digits), digits=equate.interval.digits)))),
+						scales=as.numeric(as.character(round(seq(prior.year.data.range[1L], prior.year.data.range[2L], by=0.1^equate.interval.digits), digits=equate.interval.digits)))),
 					freqtab(as.numeric(as.character(round(current.year.data[['SCALE_SCORE']], digits=equate.interval.digits))),
-						scales=as.numeric(as.character(round(seq(current.year.data.range[1], current.year.data.range[2], by=0.1^equate.interval.digits), digits=equate.interval.digits)))), type=equate.type.iter)
+						scales=as.numeric(as.character(round(seq(current.year.data.range[1L], current.year.data.range[2L], by=0.1^equate.interval.digits), digits=equate.interval.digits)))), type=equate.type.iter)
 			)
 		}
 		return(equate.list)
@@ -73,10 +73,13 @@ function(tmp.data,
 			for (equate.type.iter in equating.method) {
 				approxfun.scale <- tmp.list[[paste(content_area.iter, current.year, sep=".")]][[paste("GRADE", grade.iter, sep="_")]][[toupper(equate.type.iter)]][['NEW_TO_OLD']][['concordance']][['scale']]
 				approxfun.yx <- tmp.list[[paste(content_area.iter, current.year, sep=".")]][[paste("GRADE", grade.iter, sep="_")]][[toupper(equate.type.iter)]][['NEW_TO_OLD']][['concordance']][['yx']]
+				equate.dt <- data.table(V1=approxfun.scale, V2=approxfun.yx)
+				equate.dt.newtoold <- equate.dt[,list(V2=mean(V2, na.rm=TRUE)), by=V1]
 				tmp.list[[paste(content_area.iter, current.year, sep=".")]][[paste("GRADE", grade.iter, sep="_")]][[toupper(equate.type.iter)]][['NEW_TO_OLD']]$interpolated_function <- approxfun(
-					approxfun.scale, approxfun.yx, rule=2)
-					tmp.list[[paste(content_area.iter, current.year, sep=".")]][[paste("GRADE", grade.iter, sep="_")]][[toupper(equate.type.iter)]][['OLD_TO_NEW']]$interpolated_function <- approxfun(
-				approxfun.yx, approxfun.scale, rule=2)
+					equate.dt.newtoold[['V1']], equate.dt.newtoold[['V2']], rule=2)
+				equate.dt.oldtonew <- equate.dt[,list(V1=mean(V1, na.rm=TRUE)), by=V2]
+				tmp.list[[paste(content_area.iter, current.year, sep=".")]][[paste("GRADE", grade.iter, sep="_")]][[toupper(equate.type.iter)]][['OLD_TO_NEW']]$interpolated_function <- approxfun(
+					equate.dt.oldtonew[['V2']], equate.dt.oldtonew[['V1']], rule=2)
 			}
 		}
 	}
